@@ -7,32 +7,38 @@ from warnings import warn
 import scipp as sc
 import numpy as np
 from ._common import to_child_select
-from .typing import Group
+from .typing import H5Group
 from .nxobject import Field, NXobject, ScippIndex, NexusStructureError
 
 
 class NXdata(NXobject):
     def __init__(
             self,
-            group: Group,
+            group: H5Group,
             signal_name_default: str = None,
             signal_override: Union[Field, _EventField] = None,  # noqa: F821
             axes: List[str] = None,
             skip: List[str] = None):
         """
-        :param signal_name_default: Default signal name used, if no `signal`
-            attribute found in file.
-        :param signal_override Signal field-like to use instead of trying to read
-            signal from the file. This is used when there is no signal or to provide
-            a signal computed from NXevent_data
-        :param axes: Default axes used, if no `axes` attribute found in file.
-        :param skip: Names of fields to skip when loading coords.
+        Parameters
+        ----------
+        signal_name_default:
+            Default signal name used, if no `signal` attribute found in file.
+        signal_override:
+            Field-like to use instead of trying to read signal from the file. This is
+            used when there is no signal or to provide a signal computed from
+            NXevent_data.
+        axes:
+            Default axes used, if no `axes` attribute found in file.
+        skip:
+            Names of fields to skip when loading coords.
         """
         super().__init__(group)
         self._signal_name_default = signal_name_default
         self._signal_override = signal_override
         self._axes_default = axes
         self._skip = skip if skip is not None else []
+        self._error_suffixes = ['_error', '_errors']  # _error is the deprecated suffix
 
     @property
     def shape(self) -> List[int]:
@@ -128,11 +134,18 @@ class NXdata(NXobject):
         except NexusStructureError:
             return None
 
+    def _is_errors(self, name):
+        for suffix in self._error_suffixes:
+            if name.endswith(suffix):
+                if name[:-len(suffix)] in self:
+                    return True
+        return False
+
     def _getitem(self, select: ScippIndex) -> sc.DataArray:
         signal = self._signal[select]
         if self._errors_name in self:
             stddevs = self[self._errors_name][select]
-            signal.variances = sc.pow(stddevs, 2).values
+            signal.variances = sc.pow(stddevs, sc.scalar(2)).values
 
         da = sc.DataArray(data=signal) if isinstance(signal, sc.Variable) else signal
 
@@ -141,15 +154,19 @@ class NXdata(NXobject):
         skip += list(self.attrs.get('auxiliary_signals', []))
 
         for name, field in self.items():
-            if (not isinstance(field, Field)) or (name in skip):
+            if (not isinstance(field, Field)) or (name
+                                                  in skip) or self._is_errors(name):
                 continue
             try:
                 sel = to_child_select(self.dims, field.dims, select)
                 coord = self[name][sel]
-                # NeXus treats [] and [1] interchangeably, in general this is
-                # ill-defined, but this is the best we can do.
-                if coord.shape == [1] and da.sizes.get(coord.dim) != 1:
-                    coord = coord.squeeze()
+                for suffix in self._error_suffixes:
+                    if f'{name}{suffix}' in self:
+                        if coord.variances is not None:
+                            warn(f"Found {name}_errors as well as the deprecated "
+                                 f"{name}_error. The latter will be ignored.")
+                        stddevs = self[f'{name}{suffix}'][sel]
+                        coord.variances = sc.pow(stddevs, sc.scalar(2)).values
                 da.coords[name] = coord
             except sc.DimensionError as e:
                 warn(f"Skipped load of axis {field.name} due to:\n{e}")
